/*
 * Grdc - GTK+/Gnome Remote Desktop Client
 * Copyright (C) 2009 - Vic Lee 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, 
 * Boston, MA 02111-1307, USA.
 */
 

#ifndef __GRDCPREFDIALOG_H__
#define __GRDCPREFDIALOG_H__

/*
 * Grdc Perference Dialog
 */

G_BEGIN_DECLS

enum
{
    GRDC_PREF_OPTIONS_TAB = 0,
    GRDC_PREF_GROUPS_TAB = 1,
    GRDC_PREF_RESOLUTIONS_TAB = 2,
    GRDC_PREF_APPLET_TAB = 3
};

gboolean grdc_pref_dialog_run (GtkWindow *parent, gint default_tab);

G_END_DECLS

#endif  /* __GRDCPREFDIALOG_H__  */

